<template>
  <div class="">
    <!-- Basic Info -->
    <BaseHeading>
      {{ $t('customers.basic_info') }}
    </BaseHeading>

    <BaseDescriptionList>
      <BaseDescriptionListItem
        v-if="selectedViewTransaction.phone_number"
        :content-loading="contentLoading"
        :label="$t('mpesa.phone')"
        :value="selectedViewTransaction?.phone_number"
      />

      <BaseDescriptionListItem
        v-if="selectedViewTransaction.account_reference"
        :content-loading="contentLoading"
        :label="$t('mpesa.account_reference')"
        :value="selectedViewTransaction?.account_reference"
      />

      <BaseFormatMoney
          :content-loading="contentLoading"
          :label="$t('mpesa.amount')"
          :amount="selectedViewTransaction.amount"
      />

<!--      <BaseDescriptionListItem-->
<!--        v-if="selectedViewTransaction.amount"-->
<!--        :content-loading="contentLoading"-->
<!--        :label="$t('mpesa.amount')"-->
<!--        :value="selectedViewTransaction?.amount"-->
<!--      />-->

      <BaseDescriptionListItem
          v-if="selectedViewTransaction.CheckoutRequestID"
          :content-loading="contentLoading"
          :label="$t('mpesa.request_id')"
          :value="selectedViewTransaction?.CheckoutRequestID"
      />

    </BaseDescriptionList>

    <BaseDescriptionList>
      <BaseDescriptionListItem
          v-if="selectedViewTransaction.MerchantRequestID"
          :content-loading="contentLoading"
          :label="$t('mpesa.merchant_id')"
          :value="selectedViewTransaction?.MerchantRequestID"
      />

    </BaseDescriptionList>


    <BaseDescriptionList>
      <BaseDescriptionListItem
          v-if="selectedViewTransaction.created_at"
          :content-loading="contentLoading"
          :label="'Date'"
          :value="selectedViewTransaction?.created_at"
      />
    </BaseDescriptionList>

    <BaseHeading class="mt-6">
      Transaction Info
    </BaseHeading>

    <BaseDescriptionList>
      <BaseDescriptionListItem
          v-if="selectedViewTransaction.status"
          :content-loading="contentLoading"
          :label="'Status'"
          :value="selectedViewTransaction?.status"
      />
    </BaseDescriptionList>


    <BaseDescriptionList>
      <BaseDescriptionListItem
          v-if="selectedViewTransaction.result_description"
          :content-loading="contentLoading"
          :label="'Status Description'"
          :value="selectedViewTransaction?.result_description"
      />
    </BaseDescriptionList>


    <BaseButton variant="primary" class="mt-4" v-if="canCheckQueryStatus" @click="checkStkStatus" :loading="isSaving" :disabled="isSaving">
      <template #left="slotProps">
        <BaseIcon name="SearchIcon" :class="slotProps.class" />
      </template>
      Check Status
    </BaseButton>

  </div>
</template>

<script setup>
import {computed, ref} from 'vue'
// import { useCustomerStore } from '@/scripts/admin/stores/customer'
import { useMpesaStore } from '@/scripts/admin/stores/mpesa'
import {useRouter} from "vue-router";

const isSaving = ref(false)

const router = useRouter()

const mpesaStore = useMpesaStore()
// const customerStore = useCustomerStore()

// const selectedViewTransaction = computed(() => customerStore.selectedViewTransaction)
const selectedViewTransaction = computed(() => mpesaStore.selectedViewTransaction)

const canCheckQueryStatus = computed(() => mpesaStore.selectedViewTransaction.status === 'PENDING')

const contentLoading = computed(() => mpesaStore.isFetchingViewData)

const customerCustomFields = computed(() => {
  if (selectedViewTransaction?.value?.fields) {
    return selectedViewTransaction?.value?.fields
  }
  return []
})

async function checkStkStatus() {
  isSaving.value = true

  let data = {
    ...mpesaStore.selectedViewTransaction,
  }

  let response = null

  try {
    response = await mpesaStore.checkTransactionStatus(data)

    isSaving.value = false

  } catch (err) {
    return
    isSaving.value = false
  }

  router.push(`/admin/mpesa/${response.data.data.id}/view`)

}

</script>
